"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactRouterDom = require("react-router-dom");

var _propertyType = _interopRequireDefault(require("../property-type"));

var _apiClient = _interopRequireDefault(require("../../utils/api-client"));

var _withNotice = _interopRequireDefault(require("../../store/with-notice"));

var _propertyJson = require("../../../backend/decorators/property-json.interface");

var _recordToFormData = _interopRequireDefault(require("./record-to-form-data"));

var _appendForceRefresh = require("./utils/append-force-refresh");

var _designSystem = require("../design-system");

var _actionHeader = _interopRequireDefault(require("../app/action-header"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// const [record, updateProperty, dispatchSubmit] = useRecordState(record)

/**
 * @name EditAction
 * @category Actions
 * @description Shows form for updating a given record.
 * @private
 * @component
 */
class Edit extends _react.default.Component {
  constructor(props) {
    super(props);
    const {
      record
    } = props;
    this.handleChange = this.handleChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
    this.state = {
      record,
      loading: false
    };
    this.api = new _apiClient.default();
  }

  handleChange(propertyOrRecord, value) {
    if (typeof value === 'undefined' && propertyOrRecord.params) {
      this.setState({
        record: propertyOrRecord
      });
    } else {
      this.setState(state => ({
        record: { ...state.record,
          params: { ...state.record.params,
            [propertyOrRecord]: value
          }
        }
      }));
    }
  }

  handleSubmit(event) {
    const {
      resource,
      history,
      addNotice
    } = this.props;
    const {
      record
    } = this.state;
    const formData = (0, _recordToFormData.default)(record);
    this.setState({
      loading: true
    });
    this.api.recordAction({
      resourceId: resource.id,
      actionName: 'edit',
      recordId: record.id,
      data: formData,
      headers: {
        'Content-Type': 'multipart/form-data'
      }
    }).then(response => {
      if (response.data.notice) {
        addNotice(response.data.notice);
      }

      if (response.data.redirectUrl) {
        history.push((0, _appendForceRefresh.appendForceRefresh)(response.data.redirectUrl));
      } else {
        this.setState(state => ({
          record: { ...state.record,
            errors: response.data.record.errors
          },
          loading: false
        }));
      }
    }).catch(() => {
      this.setState({
        loading: false
      });
      addNotice({
        message: 'There was an error updating record, Check out console to see more information.',
        type: 'error'
      });
    });
    event.preventDefault();
    return false;
  }

  render() {
    const {
      resource,
      action
    } = this.props;
    const properties = resource.editProperties;
    const {
      record,
      loading
    } = this.state;
    return _react.default.createElement(_designSystem.Box, {
      as: "form",
      onSubmit: this.handleSubmit,
      flex: true,
      flexGrow: 1,
      flexDirection: "column",
      height: 1
    }, _react.default.createElement(_designSystem.DrawerContent, null, (action === null || action === void 0 ? void 0 : action.showInDrawer) ? _react.default.createElement(_actionHeader.default, this.props) : '', properties.map(property => _react.default.createElement(_propertyType.default, {
      key: property.name,
      where: _propertyJson.PropertyPlace.edit,
      onChange: this.handleChange,
      property: property,
      resource: resource,
      record: record
    }))), _react.default.createElement(_designSystem.DrawerFooter, null, _react.default.createElement(_designSystem.Button, {
      variant: "primary",
      size: "lg"
    }, "Save")));
  }

}
/**
 * @memberof Edit
 */


var _default = (0, _withNotice.default)((0, _reactRouterDom.withRouter)(Edit));

exports.default = _default;