"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ErrorBox = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _styledSystem = require("styled-system");

var _box = require("../atoms/box");

var _header = require("../atoms/header");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const variants = theme => (0, _styledSystem.variant)({
  variants: {
    success: {},
    error: {
      bg: 'paleRed',
      'box-shadow': `0 2px 0 0 ${theme.colors.red};`
    },
    info: {
      bg: 'bluePale',
      'box-shadow': `0 2px 0 0 ${theme.colors.bluePrimary};`
    }
  }
});

const StyledErrorBox = (0, _styledComponents.default)(_box.Box).withConfig({
  displayName: "error-box__StyledErrorBox",
  componentId: "sc-1trydn7-0"
})(["display:flex;align-items:center;justify-content:center;flex-direction:column;text-align:center;"]);
/**
 * @memberof ErrorBox
 * @alias ErrorBoxProps
 */

/**
 * @class
 * Prints error message
 *
 * @component
 * @example
 * return (
 * <ErrorMessageBox title={'Some error'}>
 *   <p>Text below the title</p>
 * </ErrorMessageBox>
 * )
 */
const ErrorBox = props => {
  const {
    children,
    title,
    testId
  } = props;
  return _react.default.createElement(StyledErrorBox, {
    "data-testid": testId,
    variant: "white"
  }, _react.default.createElement(_box.Box, {
    width: 1 / 2
  }, _react.default.createElement(_header.H4, {
    mb: "lg"
  }, title), children));
};

exports.ErrorBox = ErrorBox;