import React from 'react';
/**
 * @returns {void}
 * @memberof DropArea
 * @alias OnUpload
 */
declare type OnChange = (files: Array<File>) => void;
/**
 * @memberof DropArea
 * @alias FileObject
 */
declare type FileObject = {
    /**
     * File size in bytes
     */
    size: number;
    /**
     * Original file name
     */
    name: string;
    /**
     * Mime Type
     */
    type?: string;
    /**
     * Actual file buffer.
     */
    file?: File;
};
/**
 * @memberof DropArea
 */
export declare type DropZoneProps = {
    multiple?: boolean;
    /**
     * When given UI will show that file of this name and this size has been set.
     */
    files?: FileObject;
    /**
     * Callback performed when the file is dropped/selected
     */
    onChange?: OnChange;
    /**
     * Validate options
     */
    validate?: {
        /**
         * Maximum size of the uploaded file in bytes. If not defined - all files are allowed.
         */
        maxSize?: number;
        /**
         * Available mime types. When not defined - all mime types are allowed.
         */
        mimeTypes?: Array<string>;
    };
};
declare const DropZone: React.FC<DropZoneProps>;
export { DropZone };
